# Life Game

python 写的 生命游戏，基于 `pygame` .

觉得这个游戏很有意思，虽然连操作都不用，但是看着它变来变去的就很有趣:smile:

为了让其称得上游戏，我还加入了一个操作，就是可以点击屏幕，点在生命上，会让生命死去，反之创造一个生命，这增加了不少趣味性。

甚至还想把这个当作屏保使用，电脑一定时间内没有操作，就运行这个程序.........不过这是后话了。

- **安装**

  ```shell
  pip install life_game
  ```

- **运行**

  ```shell
  python -m life_game
  ```

- **操作**
  - **空格: ** 暂停游戏
  - **点击:** 复活一个生命，或者杀死一个生命
  - **F11:** 全屏
- **运行截图**

![1542644432983](https://github.com/MemoryD/life_game/blob/master/1542645279180.png)